import argparse
import os
import sys

from . import cli
from .cli import fail, print_stdout, print_stderr
from .importer import Importer


def parse_args():
    desc = _("Import virtual machine")
    parser = cli.setupParser("%(prog)s --original NAME --connect NAME "
                             "--pool NAME", desc)
    cli.add_connect_option(parser)

    geng = parser.add_argument_group(_("General Options"))
    geng.add_argument("-o", "--original", dest="tar", required=True,
                    help=_("Tar.gz archive with virtual machine"))
    geng.add_argument("-p", "--pool", dest="pool", required=True,
                      help=_("Name of pool for the virtual machine"))
    geng.add_argument("-c", "--checksum", action="store_true",
                      help=_("Compare a checksum file"))
    geng.add_argument("-s", "--save-mac", action="store_true",
                      help=_("Save MAC-address"))

    misc = parser.add_argument_group(_("Miscellaneous Options"))

    # Just used for import tests
    misc.add_argument("--__test-nodry", action="store_true", dest="test_nodry",
                      default=False, help=argparse.SUPPRESS)
    cli.add_misc_options(misc, prompt=True, replace=False, printxml=False)
    cli.autocomplete(parser)

    return parser.parse_args()


def main(conn=None):
    cli.earlyLogging()
    options = parse_args()

    cli.setupLogging("virt-import", options.debug, options.quiet)
    cli.convert_old_force(options)
    conn = cli.getConnection(options.connect, conn=conn)
    importer = Importer(conn)

    importer.start_importing(options.tar, options.pool, bool(options.checksum),
                             bool(options.save_mac))
    print_stdout("")
    print_stdout(_("Import '%s' created successfully.")
                    % options.tar)

    return 0


def runcli():  # pragma: no cover
    try:
        sys.exit(main())
    except SystemExit as sys_e:
        sys.exit(sys_e.code)
    except KeyboardInterrupt:
        print_stderr(_("Installation aborted at user request"))
    except Exception as main_e:
        fail(main_e)
